@@ -5,7 +5,8 @@ use strict;
 use base qw( Workflow::Base );
 use Carp qw(croak);
 
-$Workflow::Condition::VERSION = '1.48';
+$Workflow::Condition::CACHE_RESULTS = 1;
+$Workflow::Condition::VERSION = '1.49';
 
 my @FIELDS = qw( name class );
 __PACKAGE__->mk_accessors(@FIELDS);
@@ -203,6 +204,15 @@ C<<condition name="!some_condition">> in your workflow state definition,
 exactly one of them will succeed and one will fail - which is particularly
 useful if you use "autorun" a lot.
 
+Caching can be disabled by changing C<$Workflow::Condition::CACHE_RESULTS>
+to zero (0):
+
+    $Workflow::Condition::CACHE_RESULTS = 0;
+
+All versions before 1.49 used a mechanism that effectively caused global
+state. To address the problems that resulted (see GitHub issues #9 and #7),
+1.49 switched to a new mechanism with a cache per workflow instance.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2003-2007 Chris Winters. All rights reserved.
