@@ -3,7 +3,7 @@ package Workflow::Condition::GreedyOR;
 use strict;
 use warnings;
 
-our $VERSION = '1.48';
+our $VERSION = '1.49';
 
 use base qw( Workflow::Condition::Nested );
 use Workflow::Exception qw( condition_error configuration_error );
@@ -36,7 +36,7 @@ sub evaluate {
     my $result = 0;
 
     foreach my $cond ( @{$conditions} ) {
-        $result += $self->evaluate_condition( $wf, $cond );
+        $result += $self->evaluate_condition( $wf, $cond ) ? 1 : 0;
     }
 
     if ($result) {
